package com.yunzhi.training.common;

import cn.hutool.json.JSONObject;
import com.yunzhi.training.entity.SysUser;
import com.yunzhi.training.entity.TaPerson;
import com.yunzhi.training.service.ISysUserService;
import com.yunzhi.training.service.ITaPersonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;

@Component
public class BaseController {

    @Autowired
    ISysUserService iSysUserService;

    @Autowired
    ITaPersonService iTaPersonService;

    /**
     * 获取当前管理端人员
     * @return
     */
    public SysUser getCurrentUser(HttpServletRequest request) throws Exception {
        String token = JWTUtils.getToken(request);
        JSONObject tkJSON = JWTUtils.decode(token);

        String userId = tkJSON.get("userId", String.class);
        if (StringUtils.isEmpty(userId)) {
            throw new Exception("获取当前人员信息失败");
        }

        SysUser sysUser = iSysUserService.getById(userId);
        if (null == sysUser || Constants.STATUS_DELETED == sysUser.getState()) {
            throw new Exception("校验人员息失败, 请重试");
        }

        return sysUser;
    }

    /**
     * 获取当前小程序端人员
     * @return
     */
    public TaPerson getCurrentPerson(HttpServletRequest request) throws Exception {
        String token = JWTUtils.getToken(request);
        JSONObject tkJSON = JWTUtils.decode(token);

        String personId = tkJSON.get("userId", String.class);
        if (StringUtils.isEmpty(personId)) {
            throw new Exception("获取当前人员信息失败");
        }

        TaPerson taPerson = iTaPersonService.getById(personId);
        if (null == taPerson || Constants.STATUS_DELETED == taPerson.getState()) {
            throw new Exception("获取当前人员信息失败");
        }

        return taPerson;
    }
}
