package com.yunzhi.training.controller;

import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.ResponseBean;
import com.yunzhi.training.service.ITaSignInService;
import com.yunzhi.training.service.ITaStudentService;
import com.yunzhi.training.vo.ChartParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


@Api(tags = "数据统计")
@RestController
public class StatsController  extends BaseController {

    @Autowired
    ITaStudentService iTaStudentService;

    @Autowired
    ITaSignInService iTaSignInService;

    @RequestMapping(value="/admin/stat/student-total",method= RequestMethod.GET)
    @ApiOperation(value="各学期学生总数", notes = "各学期学生总数", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean totalStuNum() throws Exception {
        // 学生总数
        List<ChartParam> result = iTaStudentService.countByTerm();
        //
        return ResponseBean.success(result);
    }

    @RequestMapping(value="/admin/stat/student-total-class",method= RequestMethod.GET)
    @ApiOperation(value="各班级学生总数", notes = "各班级学生总数", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean totalClassStuNum(@ApiParam("学期") @RequestParam(value ="termId") String termId) throws Exception {
        // 学生总数
        List<ChartParam> result = iTaStudentService.countByClass(termId);
        //
        return ResponseBean.success(result);
    }

    @RequestMapping(value="/admin/stat/student-total-age",method= RequestMethod.GET)
    @ApiOperation(value="各年龄段学生总数", notes = "各年龄段学生总数", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean totalAgeStuNum(@ApiParam("学期") @RequestParam(value ="termId", required = false) String termId) throws Exception {
        // 学生总数
        List<ChartParam> result = iTaStudentService.countByAge(termId);
        //
        return ResponseBean.success(result);
    }

    @RequestMapping(value="/admin/stat/signin-ratio",method= RequestMethod.GET)
    @ApiOperation(value="签到率", notes = "签到率", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean signRatio() throws Exception {
        List<ChartParam> result = iTaSignInService.getRatio();
        return ResponseBean.success(result);
    }

    @RequestMapping(value="/admin/stat/signin-ratio-term",method= RequestMethod.GET)
    @ApiOperation(value="学期签到率", notes = "学期签到率", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean signRatioByTerm() throws Exception {
        List<ChartParam> result = iTaSignInService.getRatioByTerm();
        return ResponseBean.success(result);
    }

    @RequestMapping(value="/admin/stat/signin-ratio-daily",method= RequestMethod.GET)
    @ApiOperation(value="日签到率", notes = "日签到率", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean signRatioByDaily(@ApiParam(value = "起始日期", example = "2022-03-01") @RequestParam(value ="start") String start,
                                         @ApiParam(value = "天数") @RequestParam(value ="num") Integer num) throws Exception {
        List<ChartParam> result = iTaSignInService.signRatioByDaily(start, num);
        return ResponseBean.success(result);
    }

    @RequestMapping(value="/admin/stat/signin-ratio-monthly",method= RequestMethod.GET)
    @ApiOperation(value="月签到率", notes = "月签到率", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean signRatioByMonthly(@ApiParam(value = "起始月份", example = "2022-03") @RequestParam(value ="start") String start,
                                         @ApiParam(value = "月数") @RequestParam(value ="num") Integer num) throws Exception {
        List<ChartParam> result = iTaSignInService.signRatioByMonthly(start, num);
        return ResponseBean.success(result);
    }
}
