package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.Constants;
import com.yunzhi.training.common.ResponseBean;
import com.yunzhi.training.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaAttachmentService;
import com.yunzhi.training.entity.TaAttachment;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 附件表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-21
 */

@Api(tags = "附件表")
@RestController
@RequestMapping("/")
public class TaAttachmentController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaAttachmentController.class);

    @Autowired
    public ITaAttachmentService iTaAttachmentService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/attachment",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taAttachmentList(@ApiParam(value = "客户端",allowableValues = "admin,wx") @PathVariable String client,
                                         @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         @ApiParam("附件类型") @RequestParam(value ="attchType", defaultValue = "image") String attchType,
                                         @ApiParam("所属包组") @RequestParam(value ="packId", required = false) String packId) throws Exception{

        IPage<TaAttachment> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaAttachment> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(!StringUtils.isEmpty(attchType), "attch_type", attchType);
        queryWrapper.eq(!StringUtils.isEmpty(packId), "pack_id", packId);
        queryWrapper.gt("state", Constants.STATUS_DELETED);
        queryWrapper.eq("wx".equals(client), "state", Constants.STATUS_NORMAL);
        queryWrapper.orderByDesc("create_date");

        IPage<TaAttachment> result = iTaAttachmentService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taAttachment 实体对象
     * @return
     */
    @RequestMapping(value="/admin/attachment",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taAttachmentAdd(@ApiParam("保存内容") @RequestBody TaAttachment taAttachment) throws Exception{

        if (StringUtils.isEmpty(taAttachment.getUrl())) {
            return ResponseBean.error("请设置附件地址", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        if (StringUtils.isEmpty(taAttachment.getPackId())) {
            return ResponseBean.error("请设置附件包组", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        if (StringUtils.isEmpty(taAttachment.getAttchType())) {
            taAttachment.setAttchType("image");
        }

        taAttachment.setAttchId(null);

        if (iTaAttachmentService.save(taAttachment)){
            return ResponseBean.success(taAttachment);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/attachment/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taAttachmentDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaAttachmentService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taAttachment 实体对象
     * @return
     */
    @RequestMapping(value="/admin/attachment/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taAttachmentUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaAttachment taAttachment) throws Exception{
        if (StringUtils.isEmpty(taAttachment.getUrl())) {
            return ResponseBean.error("请设置附件地址", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        if (StringUtils.isEmpty(taAttachment.getPackId())) {
            return ResponseBean.error("请设置附件包组", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        if (StringUtils.isEmpty(taAttachment.getAttchType())) {
            taAttachment.setAttchType("image");
        }

        taAttachment.setAttchId(id);

        if (iTaAttachmentService.updateById(taAttachment)){
            return ResponseBean.success(iTaAttachmentService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taAttachment/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taAttachmentGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaAttachmentService.getById(id));
//    }
}
