package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.Constants;
import com.yunzhi.training.common.ResponseBean;
import com.yunzhi.training.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaBannerService;
import com.yunzhi.training.entity.TaBanner;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * Banner表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-21
 */

@Api(tags = "Banner表")
@RestController
@RequestMapping("/")
public class TaBannerController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaBannerController.class);

    @Autowired
    public ITaBannerService iTaBannerService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/banner",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taBannerList(@ApiParam(value = "客户端",allowableValues = "admin,wx") @PathVariable String client,
                                     @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                     @ApiParam("位置") @RequestParam(value ="position", required = false) String position) throws Exception{

        if (!"admin".equals(client) && !"wx".equals(client)) {
            return ResponseBean.error("不支持的请求", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        IPage<TaBanner> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaBanner> queryWrapper = new QueryWrapper<>();
        queryWrapper.gt("admin".equals(client), "state", Constants.STATUS_DELETED);
        queryWrapper.eq("wx".equals(client), "state", Constants.STATUS_NORMAL);
        queryWrapper.eq(!StringUtils.isEmpty(position), "position", position);
        queryWrapper.orderByDesc("sort_no");

        IPage<TaBanner> result = iTaBannerService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taBanner 实体对象
     * @return
     */
    @RequestMapping(value="/admin/banner",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taBannerAdd(@ApiParam("保存内容") @RequestBody TaBanner taBanner) throws Exception{

//        if (StringUtils.isEmpty(taBanner.getCourseId())) {
//            return ResponseBean.error("请设置关联课程", ResponseBean.ERROR_ILLEGAL_PARAMS);
//        }

        if (StringUtils.isEmpty(taBanner.getTitle())) {
            return ResponseBean.error("Banner 名称不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taBanner.setBannerId(null);

        if (iTaBannerService.save(taBanner)){
            return ResponseBean.success(taBanner);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/banner/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taBannerDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaBannerService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taBanner 实体对象
     * @return
     */
    @RequestMapping(value="/admin/banner/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taBannerUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaBanner taBanner) throws Exception{

        taBanner.setBannerId(id);
        if (StringUtils.isEmpty(taBanner.getTitle())) {
            return ResponseBean.error("Banner 名称不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (iTaBannerService.updateById(taBanner)){
            return ResponseBean.success(iTaBannerService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/banner/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taBannerGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaBannerService.getExistBy("banner_id", id, false, true));
    }
}
