package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.ResponseBean;
import com.yunzhi.training.common.StringUtils;
import com.yunzhi.training.entity.TaPerson;
import com.yunzhi.training.vo.FavoriteTarget;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaFavoritesService;
import com.yunzhi.training.entity.TaFavorites;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 我的收藏 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-22
 */

@Api(tags = "我的收藏")
@RestController
@RequestMapping("/")
public class TaFavoritesController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaFavoritesController.class);

    @Autowired
    public ITaFavoritesService iTaFavoritesService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/favorite",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taFavoritesList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                        @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                        HttpServletRequest request) throws Exception{

        TaPerson taPerson = getCurrentPerson(request);

        IPage<FavoriteTarget> pg = new Page<>(pageNum, pageSize);
        IPage<FavoriteTarget> result = iTaFavoritesService.getMyFavorites(pg, taPerson.getPersonId());
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taFavorites 实体对象
     * @return
     */
    @RequestMapping(value="/wx/favorite",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taFavoritesAdd(@ApiParam("保存内容") @RequestBody TaFavorites taFavorites,
                                       HttpServletRequest request) throws Exception{
        TaPerson taPerson = getCurrentPerson(request);

        if (StringUtils.isEmpty(taFavorites.getTargetType())
                || StringUtils.isEmpty(taFavorites.getTargetId())
                || StringUtils.isEmpty(taFavorites.getTargetName())) {
            return ResponseBean.error("未找到有效收藏内容", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaFavorites origin = iTaFavoritesService.getByPerson(taFavorites.getTargetType(), taFavorites.getTargetId(), taPerson.getPersonId());
        if (origin != null) {
            return ResponseBean.error("您已收藏, 请勿重复操作", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taFavorites.setFavId(null);
        taFavorites.setPersonId(taPerson.getPersonId());

        if (iTaFavoritesService.save(taFavorites)){
            return ResponseBean.success(taFavorites);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param taFavorites  收藏内容
     */
    @RequestMapping(value="/wx/favorite", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taFavoritesDelete(@ApiParam("收藏内容") @RequestBody TaFavorites taFavorites,
                                          HttpServletRequest request) throws Exception{
        TaPerson taPerson = getCurrentPerson(request);
        TaFavorites origin = iTaFavoritesService.getByPerson(taFavorites.getTargetType(), taFavorites.getTargetId(), taPerson.getPersonId());
        if (null == taFavorites) {
            ResponseBean.success("success");
        }

        if(iTaFavoritesService.removeById(origin.getFavId())){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taFavorites 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taFavorites/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taFavoritesUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaFavorites taFavorites) throws Exception{
//
//        if (iTaFavoritesService.updateById(taFavorites)){
//            return ResponseBean.success(iTaFavoritesService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taFavorites/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taFavoritesGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaFavoritesService.getById(id));
//    }
}
