package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.Constants;
import com.yunzhi.training.common.ResponseBean;
import com.yunzhi.training.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaSchoolTermService;
import com.yunzhi.training.entity.TaSchoolTerm;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;

/**
 * <p>
    * 学期 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-21
 */

@Api(tags = "学期")
@RestController
@RequestMapping("/")
public class TaSchoolTermController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaSchoolTermController.class);

    @Autowired
    public ITaSchoolTermService iTaSchoolTermService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/school-term",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taSchoolTermList(@ApiParam(value = "客户端",allowableValues = "admin,wx") @PathVariable String client,
                                         @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         @ApiParam("名称") @RequestParam(value ="name", required = false) String name) throws Exception{

        if (!"admin".equals(client) && !"wx".equals(client)) {
            return ResponseBean.error("不支持的请求", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        IPage<TaSchoolTerm> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaSchoolTerm> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(name), "name", "%"+name+"%");
        queryWrapper.gt("admin".equals(client), "state", Constants.STATUS_DELETED);
        queryWrapper.eq("wx".equals(client), "state", Constants.STATUS_NORMAL);
        queryWrapper.orderByDesc("create_date");

        IPage<TaSchoolTerm> result = iTaSchoolTermService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taSchoolTerm 实体对象
     * @return
     */
    @RequestMapping(value="/admin/school-term",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taSchoolTermAdd(@ApiParam("保存内容") @RequestBody TaSchoolTerm taSchoolTerm) throws Exception{

        if (StringUtils.isEmpty(taSchoolTerm.getName())) {
            return ResponseBean.error("学期名称不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        int cnt = iTaSchoolTermService.countBy("name", taSchoolTerm.getName(), true);
        if (cnt > 0) {
            return ResponseBean.error("学期名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taSchoolTerm.setTermId(null);
        taSchoolTerm.setCreateDate(LocalDateTime.now());

        if (iTaSchoolTermService.save(taSchoolTerm)){
            return ResponseBean.success(taSchoolTerm);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/school-term/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taSchoolTermDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaSchoolTermService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taSchoolTerm 实体对象
     * @return
     */
    @RequestMapping(value="/admin/school-term/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taSchoolTermUpdate(@ApiParam("对象ID") @PathVariable String id,
                                           @ApiParam("更新内容") @RequestBody TaSchoolTerm taSchoolTerm) throws Exception{

        if (StringUtils.isEmpty(taSchoolTerm.getName())) {
            return ResponseBean.error("学期名称不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaSchoolTerm origin = iTaSchoolTermService.getById(id);
        if (null == origin || Constants.STATUS_DELETED == origin.getState()) {
            return ResponseBean.error("更新失败, 未找到有效资源", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaSchoolTerm exist = iTaSchoolTermService.getByButNot("name", taSchoolTerm.getName(), "term_id", id, true);
        if (exist != null) {
            return ResponseBean.error("学期名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        origin.setName(taSchoolTerm.getName());
        origin.setState(taSchoolTerm.getState());

        if (iTaSchoolTermService.updateById(origin)){
            return ResponseBean.success(origin);
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/{client}/school-term/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taSchoolTermGet(@ApiParam(value = "客户端",allowableValues = "admin,wx") @PathVariable String client,
                                        @ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaSchoolTermService.getExistBy("term_id", id, "wx".equals(client), true));
    }
}
