package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.ResponseBean;
import com.yunzhi.training.common.StringUtils;
import com.yunzhi.training.service.ITaSignInService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaSignClassService;
import com.yunzhi.training.entity.TaSignClass;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
    * 预签到班级 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-23
 */

@Api(tags = "预签到班级")
@RestController
@RequestMapping("/")
public class TaSignClassController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaSignClassController.class);

    @Autowired
    public ITaSignClassService iTaSignClassService;

    @Autowired
    public ITaSignInService iTaSignInService;

    /**
     * 分页查询列表
     * @return
     */
    @RequestMapping(value="/admin/sign-class",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taSignClassList(@ApiParam("签到ID") @RequestParam(value ="signId") String signId) throws Exception{

        QueryWrapper<TaSignClass> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("sign_id", signId);
        queryWrapper.orderByDesc("term_id");
        queryWrapper.orderByDesc("class_id");

        List<TaSignClass> result = iTaSignClassService.list(queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param signId 签到ID
     * @param signClassList 保存内容
     * @return
     */
    @RequestMapping(value="/admin/sign-class",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taSignClassAdd(@ApiParam("签到ID") @RequestParam(value ="signId") String signId,
                                       @ApiParam("保存内容") @RequestBody List<TaSignClass> signClassList) throws Exception{

        iTaSignClassService.removeBySign(signId);

        if (!iTaSignClassService.saveBatch(signClassList)) {
            // 反更新签到数据
            iTaSignInService.updateTotalNum(signId);

            return ResponseBean.error("操作失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }

        return ResponseBean.success(signClassList);
    }

    /**
     * 根据id删除对象
     * @param signId  签到ID
     * @param termId  学期ID
     * @param classId  班级ID
     */
    @RequestMapping(value="/admin/sign-class", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taSignClassDelete(@ApiParam("签到ID") @RequestParam(value ="signId") String signId,
                                          @ApiParam("学期ID") @RequestParam(required = false) String termId,
                                          @ApiParam("班级ID") @RequestParam(required = false) String classId) throws Exception{
        if(iTaSignClassService.removeBy(signId, termId, classId)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taSignClass 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taSignClass/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taSignClassUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaSignClass taSignClass) throws Exception{
//
//        if (iTaSignClassService.updateById(taSignClass)){
//            return ResponseBean.success(iTaSignClassService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taSignClass/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taSignClassGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaSignClassService.getById(id));
//    }
}
