package com.yunzhi.training.interceptor;

import cn.hutool.json.JSONUtil;
import com.yunzhi.training.common.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.nio.charset.StandardCharsets;

@Slf4j
@Component
public class PermissionInterceptor implements HandlerInterceptor {

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object obj) throws Exception {
        // 请求地址
        String uri = request.getRequestURI();
//        if (uri.contains("/wx/")) {
//            boolean isWx = checkWx(request);
//            if (!isWx) {
//                responseTokenError(response, "请使用微信客户端访问");
//                return false;
//            }
//        }

        String token = JWTUtils.getToken(request);

        try {
            JWTUtils.verify(token);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("鉴权失败: {}", e.getMessage());
            responseTokenError(response, "鉴权失败, 请重新登录");
            return false;
        }

        return true;
    }

    @Override
    public void postHandle(HttpServletRequest request, HttpServletResponse response, Object handler, ModelAndView modelAndView) throws Exception {
        // 刷新 TOKEN
        String jws = JWTUtils.getToken(request);
        JWTUtils.refresh(jws, response);
    }

    private void responseTokenError(HttpServletResponse response, String error) throws IOException {
        response.addHeader("Content-type", "application/json");
        byte[] data = JSONUtil.toJsonStr(ResponseBean.error(error, ResponseBean.ERROR_AUTH_FAIL)).getBytes(StandardCharsets.UTF_8);
        response.getOutputStream().write(data);

    }

    private boolean checkWx(HttpServletRequest request) {
        String ua = request.getHeader("user-agent");
        return ua.toLowerCase().contains("micromessenger");
    }
}
