package com.yunzhi.training.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.yunzhi.training.common.Constants;
import com.yunzhi.training.common.StringUtils;
import com.yunzhi.training.entity.*;
import com.yunzhi.training.mapper.TaAnswerMapper;
import com.yunzhi.training.mapper.TaQuePersonMapper;
import com.yunzhi.training.mapper.TaQuestionMapper;
import com.yunzhi.training.mapper.TaQuestionPersonMapper;
import com.yunzhi.training.service.ITaQuePersonService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Optional;

/**
 * <p>
 * 问卷参与人 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2022-02-21
 */
@Service
public class TaQuePersonServiceImpl extends ServiceImpl<TaQuePersonMapper, TaQuePerson> implements ITaQuePersonService {

    @Autowired
    TaQuestionMapper taQuestionMapper;

    @Autowired
    TaAnswerMapper taAnswerMapper;

    @Autowired
    TaQuestionPersonMapper taQuestionPersonMapper;

    @Override
    public TaQuePerson getPersonRecord(String id, String personId) {
        QueryWrapper<TaQuePerson> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("que_id", id).eq("person_id", personId).eq("state", Constants.STATUS_NORMAL);

        return getOne(queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean answer(TaQuestionnaire taQues, TaPerson taPerson, List<TaQuestionPerson> questionPersonList) throws Exception {
        //
        List<TaQuestion> questionList = taQuestionMapper.getByQueID(taQues.getQueId(), true);

        // 必须全部作答
        if (questionList.size() != questionPersonList.size()) {
            throw new Exception("尚有未完成的题目");
        }

        //
        List<TaAnswer> answerList = taAnswerMapper.getAllAnswers(taQues.getQueId());

        String personId = taPerson.getPersonId();

        Integer totalScore = null;
        for (TaQuestionPerson questionPerson : questionPersonList) {
            String questionId = questionPerson.getQuestionId();
            if (StringUtils.isEmpty(questionId)) {
                throw new Exception("应答找不到对应题目");
            }

            String answerOptStr = questionPerson.getAnswerOpt();
            String answerText = questionPerson.getAnswerText();
            if (StringUtils.isEmpty(answerOptStr) && StringUtils.isEmpty(answerText)) {
                throw new Exception("存在未作答的题目");
            }

            Optional<TaQuestion> question = questionList.stream().filter(x -> x.getQuestionId().equals(questionId)).findFirst();
            if (!question.isPresent()) {
                throw new Exception("应答题目与题库不匹配");
            }

            // 如果是单选题, 则去校验是否存在分数
            if (question.get().getQuestionType().equals(Constants.QUESTION_RADIO)) {
                Optional<TaAnswer> answer = answerList.stream().filter(x -> x.getQuestionId().equals(questionId) && x.getOptCode().equals(answerOptStr)).findFirst();
                if (!answer.isPresent()) {
                    throw new Exception("应答题目错误");
                }

                TaAnswer taAnswer = answer.get();
                Integer score = taAnswer.getScore();
                if (null != score && score > 0) {
                    if (totalScore == null) {
                        totalScore = 0;
                    }
                    totalScore += score;
                    questionPerson.setScore(score);
                }
            }

            questionPerson.setSerialNo(null);
            questionPerson.setPersonId(personId);
            questionPerson.setState(Constants.STATUS_NORMAL);

            if (taQuestionPersonMapper.insert(questionPerson) < 1) {
                throw new Exception("应答入库失败");
            }
        }

        TaQuePerson quePerson = new TaQuePerson();
        quePerson.setPersonId(personId);
        quePerson.setQueId(taQues.getQueId());
        quePerson.setScore(totalScore);
        quePerson.setState(Constants.STATUS_NORMAL);

        if (!save(quePerson)) {
            throw new Exception("应答失败, 请重试");
        }

        return true;
    }
}
