package com.yunzhi.training.service.impl;

import com.yunzhi.training.entity.TaPerson;
import com.yunzhi.training.entity.TaSignIn;
import com.yunzhi.training.entity.TaSignPerson;
import com.yunzhi.training.entity.TaStudent;
import com.yunzhi.training.mapper.TaSignInMapper;
import com.yunzhi.training.mapper.TaSignPersonMapper;
import com.yunzhi.training.mapper.TaStudentMapper;
import com.yunzhi.training.service.ITaSignPersonService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 * 人员签到表 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2022-02-21
 */
@Service
public class TaSignPersonServiceImpl extends ServiceImpl<TaSignPersonMapper, TaSignPerson> implements ITaSignPersonService {

    @Autowired
    TaStudentMapper taStudentMapper;

    @Autowired
    TaSignInMapper taSignInMapper;

    @Override
    public TaSignPerson getSignRecord(TaPerson taPerson, String signId) {
        return baseMapper.getSignRecord(taPerson.getPhone(), signId);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean sign(String id, TaPerson taPerson) throws Exception {
        TaSignPerson signPerson = new TaSignPerson();
        signPerson.setSignId(id);
        signPerson.setPersonId(taPerson.getPersonId());
        signPerson.setPhone(taPerson.getPhone());

        TaStudent student = taStudentMapper.getByPerson(taPerson.getPersonId(), taPerson.getPhone());
        if (null != student && student.getPersonId().equals(taPerson.getPersonId())) {
            signPerson.setStudentId(student.getStudentId());
            signPerson.setTermId(student.getTermId());
            signPerson.setClassId(student.getClassId());
        }

        taSignInMapper.addNum(id, 1);

        return save(signPerson);
    }
}
